# Pronouns

A pronoun is a word that can substitute for a noun or a noun phrase.

There are several common types of mistakes made in pronoun usage. The most frequent mistake, involving pronoun-antecedent agreement, is covered in the [Pronoun Agreement](./pronoun_agreement.md) section of this tutorial.

This particular section will cover mistakes in the use of relative, personal, and reflexive pronouns, as well as pronoun reference, and in the use of gender-neutral language.

When used in questions, who is the nominative form of the pronoun, and it should be used when the pronoun is the subject.

```example
Correct: Who is finished with the first assignment? He is finished with the assignment.
```


Whom should be used in questions when the pronoun is the object of the verb or preposition.

```example
Correct: Whom do you like best? I like him.
```


```example
Correct: Whom did you meet at the conference? I met them.
```


Who, whom, and whose are also used to introduce clauses. Whom should be used when the pronoun is the object of the verb in the clause or the object of the preposition. Whose expresses possession.

```example
Correct: I do not remember whom my friend recommended.
```


```example
Correct: I do not remember whose recommendation it was.
```


```example
Correct: John was the person who was recommended for the internship.
```


## Personal and Reflexive Pronouns (I, Me, Myself)


```example
Incorrect: The teacher asked Anne and myself to do a peer review of each other's writing.
```


Here, the pronoun myself is used incorrectly. Myself is a reflexive pronoun. Reflexive pronouns are used when the subject and the object are the same. It can also be used for emphasis.

The sentence above should be corrected to:

```example
Correct: The teacher asked Anne and me to do a peer review of each other's writing.
```


Here are examples when the reflexive pronoun is used correctly:

```example
Correct: I'll do this assignment myself.
```


```example
Correct: I myself was scared to go into the dark room.
```


Another error occurs when, instead of using the objective form of the personal pronoun (me, him, her, etc.), we use the subjective form (I, he, she, etc.).

```example
Incorrect: This peer review needs to be completed by Anne and I.
```


The phrase completed by requires an object, so we should use the objective form of the first person pronoun -- me.

```example
Correct: This peer review needs to be completed by Anne and me.
```


In order to make the sentence sound more formal, users often substitute I with myself incorrectly.

```example
Incorrect: John and myself will join you later at the reception.
```


In the above sentence, we should use I instead of myself. Both John and I are subjects in that sentence; therefore, the subjective form of the pronoun should be used. We certainly cannot say:

```example
Incorrect: Myself will join you later at the reception.
```


Here's the corrected sentence:

```example
Correct: John and I will join you later at the reception.
```


## Vague or Ambiguous Reference


Vague (or no) reference to the antecedent is one of the most common errors made by writers at many levels, as is the ambiguous use of pronouns as the subjects of sentences.

```example
Ambiguous: Tina and her mother went out, even though she didn't want to.
```


Here it is not clear who she refers to. To correct this error, simply make it clear who she is:

```example
Preferred: Tina and her mother went out, even though Tina didn't want to.
```


Consider the following example:

```example
Ambiguous: Cough syrup and cold pills are cheap. This is what you can use to fight your cold most effectively.
```


What this refers to is vague. It could either mean the cough syrup or the pills, or even both. To make the second sentence less ambiguous, remove this and clarify. There are many possible solutions; here is one:

```example
Preferred: Cough syrup and cold pills are cheap. Patients need both to fight cold most effectively.
```


You should be used only when referring directly to the reader.

```example
Ambiguous: Doctors recommend that you should take multivitamins on a regular basis.
```


```example
Preferred: Doctors recommend taking multivitamins on a regular basis.
```


```example
Ambiguous: She sang beautifully. This made the audience cheer her.
```


```example
Preferred: Her beautiful singing made the audience cheer.
```


## Gender-neutral Language

The use of gender-neutral language, while not specifically a grammatical issue, can be an important stylistic concern.

```example
Neutral: Everyone has a preference as to what to put on a hamburger.
```

